pub struct ActivationStats {
pub mean: Array1<f32>,
pub variance: Array1<f32>,
pub max: Array1<f32>,
pub min: Array1<f32>,
pub sparsity: f32,
pub l2_norm: f32,
pub num_steps: usize,
/* private fields */
}Expand description
Running statistics over a sequence of activations.
Uses Welford’s online algorithm for numerically stable mean/variance.
Fields
mean: Array1<f32>Per-dimension mean
variance: Array1<f32>Per-dimension variance (population variance)
max: Array1<f32>Per-dimension maximum encountered value
min: Array1<f32>Per-dimension minimum encountered value
sparsity: f32Fraction of values with absolute value below eps (default 1e-6)
l2_norm: f32Global L2 norm (average over all steps)
num_steps: usizeNumber of activation vectors accumulated
Implementations
Sourceimpl ActivationStats
impl ActivationStats
Sourcepub fn from_sequence(activations: &[Array1<f32>]) -> ModelResult<Self>
pub fn from_sequence(activations: &[Array1<f32>]) -> ModelResult<Self>
Compute statistics from a fixed batch of activations.
Returns an error if the slice is empty or dimensions are inconsistent.